@@ -24,7 +24,7 @@ def send_log_email():
     sender = sender_email_configuration.sender_email_address
 
     email_configuration = EmailConfiguration.objects.filter(
-        Logs_Type='Attachment').values('HTML_File', 'Subject', 'Email_Content',
+        Logs_Type='ATTACHMENT').values('HTML_File', 'Subject', 'Email_Content',
                                        'Signature', 'Email_Us', 'FAQ_URL',
                                        'Unsubscribe_Email_ID', 'Logs_Type'
                                        ).first()
